@@ -695,7 +695,8 @@ def get_package_version(package_name: str) -> str:
 
 
 def _get_freeze_source_packages(
-    exclude: Container[str] = ()
+    exclude: Container[str] = (),
+    include: Union[str, Collection[str]] = ()
 ) -> Dict[str, str]:
     """
     Get a dictionary of package names mapped to a version requirement
@@ -710,7 +711,8 @@ def _get_freeze_source_packages(
         source_package_name = source_package_name.replace('_', '-')
         package_version = f'{source_package_name}=={version}'
         if source_package_name not in exclude:
-            source_package_names[source_package_name] = package_version
+            if (not include) or (source_package_name in include):
+                source_package_names[source_package_name] = package_version
     return source_package_names
 
 
@@ -754,6 +756,21 @@ def get_package_requirements(
             break
 
 
+def _flatten_requirements(requirements: Iterable[str]) -> Iterable[str]:
+    return chain(*(
+        (normalized_package_name,) +
+        tuple(get_package_requirements(normalized_package_name))
+        for normalized_package_name in (
+            package_name.replace('_', '-')
+            for package_name in (
+                (requirements,)
+                if isinstance(requirements, str) else
+                requirements
+            )
+        )
+    ))
+
+
 def get_freeze(
     editable: bool = False,
     exclude: Union[str, Collection[str]] = (),
@@ -770,23 +787,14 @@ def get_freeze(
     """
     package_version: str
     package_name: str
+    # Normalize excluded/included package names and expand to include packages
+    # required by the excluded/included package
+    exclude = set(_flatten_requirements(exclude))
+    include = set(_flatten_requirements(include))
     source_package_names: Dict[str, str] = _get_freeze_source_packages(
-        exclude=exclude
+        exclude=exclude,
+        include=include
     )
-    # Normalize excluded package names and expand to include packages
-    # required by the excluded package
-    exclude = set(chain(
-        (normalized_package_name,) +
-        tuple(get_package_requirements(normalized_package_name))
-        for normalized_package_name in (
-            package_name.replace('_', '-')
-            for package_name in (
-                (exclude,)
-                if isinstance(exclude, str) else
-                exclude
-            )
-        )
-    ))
     # Get the output of `pip freeze`
     status: int
     output: str
@@ -819,13 +827,14 @@ def get_freeze(
                 f'{get_package_version(package_name)}'
             )
         if package_name not in exclude:
-            # Make sure the package wasn't among the source packages already
-            # yielded
-            if package_name in source_package_names:
-                if editable:
+            if (not include) or (package_name in include):
+                # Make sure the package wasn't among the source packages
+                # already yielded
+                if package_name in source_package_names:
+                    if editable:
+                        yield package_version
+                        del source_package_names[package_name]
+                else:
                     yield package_version
-                    del source_package_names[package_name]
-            else:
-                yield package_version
     for package_version in source_package_names.values():
         yield package_version
